from django.core.urlresolvers import reverse
from django.shortcuts import get_object_or_404, render, redirect

from example.forms import ProductForm
from example.models import Product


def add_edit_product(request, product_id=None):
    if product_id:
        product = get_object_or_404(Product, id=product_id)
    else:
        product = None

    if request.method == 'POST':
        form = ProductForm(instance=product, data=request.POST, files=request.FILES)
        if form.is_valid():
            product = form.save()
            return redirect(reverse('example-edit-product', args=[product.id]))
    else:
        form = ProductForm(instance=product)

    return render(request, 'example/product.html', dictionary={
        'form': form,
        'product': product,
    })



from django.db import models


class Product(models.Model):
    name = models.CharField(max_length=255)
    description = models.TextField()
    image = models.ImageField(upload_to='examples/', blank=True)



from django.conf.urls.defaults import patterns, url


urlpatterns = patterns('example.views',
    url(r'^add/$', 'add_edit_product', name='example-add-product'),
    url(r'^edit/(?P<product_id>\d+)/$', 'add_edit_product', name='example-edit-product'),
)



from django import forms

from ajax_upload.widgets import AjaxClearableFileInput

from example.models import Product


class ProductForm(forms.ModelForm):
    class Meta:
        model = Product
        widgets = {
            'image': AjaxClearableFileInput
        }



from setuptools import setup, find_packages

import ajax_upload


setup(
    name='django-ajax-upload-widget',
    packages=find_packages(exclude=['example']),
    include_package_data=True,
    zip_safe=False,  # Because of static and template files
    version=ajax_upload.__version__,
    description=ajax_upload.__doc__,
    long_description=open('README.rst').read(),
    classifiers=[
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Topic :: Software Development'
    ],
    author='Zach Mathew',
    url='http://github.com/zmathew/django-ajax-upload-widget',
    license='BSD',
)
